"""This file is automatically generated by equivalent_timezone_ids.py"""

import datetime


lookup = (
    datetime.datetime(1970, 1, 2, 0, 0),
    {
        datetime.timedelta(days=-1, seconds=43200): (
            datetime.datetime(1979, 10, 2, 0, 0),
            {
                datetime.timedelta(days=-1, seconds=43200): (
                    datetime.datetime(1993, 8, 22, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=43200): {"Etc/GMT+12"},
                        datetime.timedelta(seconds=43200): {
                            "Kwajalein",
                            "Pacific/Kwajalein",
                        },
                    },
                ),
                datetime.timedelta(days=-1, seconds=46800): {
                    "Pacific/Enderbury",
                    "Pacific/Kanton",
                },
            },
        ),
        datetime.timedelta(days=-1, seconds=46800): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=46800): (
                    datetime.datetime(2010, 9, 26, 15, 0),
                    {
                        datetime.timedelta(days=-1, seconds=46800): (
                            datetime.datetime(2011, 12, 31, 21, 0),
                            {
                                datetime.timedelta(days=-1, seconds=46800): {
                                    "Etc/GMT+11",
                                    "Pacific/Midway",
                                    "Pacific/Niue",
                                    "Pacific/Pago_Pago",
                                    "Pacific/Samoa",
                                    "US/Samoa",
                                },
                                datetime.timedelta(seconds=46800): {"Pacific/Fakaofo"},
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=50400): {"Pacific/Apia"},
                    },
                ),
                datetime.timedelta(days=-1, seconds=50400): (
                    datetime.datetime(1983, 10, 30, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=50400): {
                            "America/Adak",
                            "America/Atka",
                            "US/Aleutian",
                        },
                        datetime.timedelta(days=-1, seconds=54000): {"America/Nome"},
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=48000): {"Pacific/Kiritimati"},
        datetime.timedelta(days=-1, seconds=48600): {"Pacific/Rarotonga"},
        datetime.timedelta(days=-1, seconds=50400): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=50400): {
                    "Etc/GMT+10",
                    "HST",
                    "Pacific/Honolulu",
                    "Pacific/Johnston",
                    "Pacific/Tahiti",
                    "US/Hawaii",
                },
                datetime.timedelta(days=-1, seconds=54000): {
                    "America/Anchorage",
                    "US/Alaska",
                },
            },
        ),
        datetime.timedelta(days=-1, seconds=52200): {"Pacific/Marquesas"},
        datetime.timedelta(days=-1, seconds=54000): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=54000): (
                    datetime.datetime(1973, 10, 28, 18, 0),
                    {
                        datetime.timedelta(days=-1, seconds=54000): {
                            "Etc/GMT+9",
                            "Pacific/Gambier",
                        },
                        datetime.timedelta(days=-1, seconds=57600): {"America/Dawson"},
                    },
                ),
                datetime.timedelta(days=-1, seconds=57600): {"America/Yakutat"},
            },
        ),
        datetime.timedelta(days=-1, seconds=55800): {"Pacific/Pitcairn"},
        datetime.timedelta(days=-1, seconds=57600): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=57600): (
                    datetime.datetime(1972, 4, 30, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=57600): (
                            datetime.datetime(1976, 4, 25, 15, 0),
                            {
                                datetime.timedelta(days=-1, seconds=57600): (
                                    datetime.datetime(1980, 4, 27, 15, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=57600): {
                                            "Etc/GMT+8"
                                        },
                                        datetime.timedelta(days=-1, seconds=61200): {
                                            "America/Whitehorse",
                                            "Canada/Yukon",
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=61200): {
                                    "America/Ensenada",
                                    "America/Santa_Isabel",
                                    "America/Tijuana",
                                    "Mexico/BajaNorte",
                                },
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=61200): {"America/Inuvik"},
                    },
                ),
                datetime.timedelta(days=-1, seconds=61200): (
                    datetime.datetime(1972, 10, 30, 0, 0),
                    {
                        datetime.timedelta(days=-1, seconds=57600): (
                            datetime.datetime(1974, 1, 6, 18, 0),
                            {
                                datetime.timedelta(days=-1, seconds=57600): (
                                    datetime.datetime(2015, 11, 1, 21, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=57600): {
                                            "America/Vancouver",
                                            "Canada/Pacific",
                                        },
                                        datetime.timedelta(days=-1, seconds=61200): {
                                            "America/Fort_Nelson"
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=61200): (
                                    datetime.datetime(1980, 4, 28, 0, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=57600): {
                                            "America/Juneau"
                                        },
                                        datetime.timedelta(days=-1, seconds=61200): (
                                            datetime.datetime(1983, 10, 30, 21, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=54000
                                                ): {"America/Sitka"},
                                                datetime.timedelta(
                                                    days=-1, seconds=57600
                                                ): (
                                                    datetime.datetime(
                                                        1984, 4, 29, 21, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=57600
                                                        ): {"America/Metlakatla"},
                                                        datetime.timedelta(
                                                            days=-1, seconds=61200
                                                        ): {
                                                            "America/Los_Angeles",
                                                            "PST8PDT",
                                                            "US/Pacific",
                                                        },
                                                    },
                                                ),
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=61200): {
                            "America/Dawson_Creek"
                        },
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=61200): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=61200): (
                    datetime.datetime(1972, 4, 30, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=61200): (
                            datetime.datetime(1996, 4, 7, 15, 0),
                            {
                                datetime.timedelta(days=-1, seconds=61200): {
                                    "America/Creston",
                                    "America/Phoenix",
                                    "Etc/GMT+7",
                                    "MST",
                                    "US/Arizona",
                                },
                                datetime.timedelta(days=-1, seconds=64800): (
                                    datetime.datetime(1999, 4, 4, 15, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=61200): {
                                            "America/Hermosillo"
                                        },
                                        datetime.timedelta(days=-1, seconds=64800): (
                                            datetime.datetime(2010, 4, 5, 0, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=64800
                                                ): {
                                                    "America/Mazatlan",
                                                    "Mexico/BajaSur",
                                                },
                                                datetime.timedelta(
                                                    days=-1, seconds=68400
                                                ): {"America/Bahia_Banderas"},
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=64800): (
                            datetime.datetime(1972, 10, 29, 21, 0),
                            {
                                datetime.timedelta(days=-1, seconds=61200): (
                                    datetime.datetime(1999, 11, 1, 0, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=61200): {
                                            "America/Edmonton",
                                            "America/Yellowknife",
                                            "Canada/Mountain",
                                        },
                                        datetime.timedelta(days=-1, seconds=64800): {
                                            "America/Cambridge_Bay"
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=64800): {
                                    "America/Swift_Current"
                                },
                            },
                        ),
                    },
                ),
                datetime.timedelta(days=-1, seconds=64800): (
                    datetime.datetime(1974, 1, 6, 18, 0),
                    {
                        datetime.timedelta(days=-1, seconds=61200): {"America/Boise"},
                        datetime.timedelta(days=-1, seconds=64800): (
                            datetime.datetime(1992, 10, 25, 18, 0),
                            {
                                datetime.timedelta(days=-1, seconds=61200): (
                                    datetime.datetime(2003, 10, 26, 15, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=61200): (
                                            datetime.datetime(2010, 11, 7, 21, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=61200
                                                ): {
                                                    "America/Denver",
                                                    "America/Shiprock",
                                                    "MST7MDT",
                                                    "Navajo",
                                                    "US/Mountain",
                                                },
                                                datetime.timedelta(
                                                    days=-1, seconds=64800
                                                ): {"America/North_Dakota/Beulah"},
                                            },
                                        ),
                                        datetime.timedelta(days=-1, seconds=64800): {
                                            "America/North_Dakota/New_Salem"
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=64800): {
                                    "America/North_Dakota/Center"
                                },
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=64800): (
            datetime.datetime(1970, 3, 29, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=61200): {
                    "Chile/EasterIsland",
                    "Pacific/Easter",
                },
                datetime.timedelta(days=-1, seconds=64800): (
                    datetime.datetime(1970, 4, 26, 15, 0),
                    {
                        datetime.timedelta(days=-1, seconds=64800): (
                            datetime.datetime(1972, 4, 30, 21, 0),
                            {
                                datetime.timedelta(days=-1, seconds=64800): (
                                    datetime.datetime(1973, 5, 1, 15, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=64800): (
                                            datetime.datetime(1973, 11, 25, 18, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=64800
                                                ): (
                                                    datetime.datetime(
                                                        1973, 12, 5, 21, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=64800
                                                        ): (
                                                            datetime.datetime(
                                                                1979, 2, 26, 0, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=64800,
                                                                ): (
                                                                    datetime.datetime(
                                                                        1981,
                                                                        12,
                                                                        27,
                                                                        0,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=64800,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1987,
                                                                                5,
                                                                                4,
                                                                                0,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=64800,
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        1988,
                                                                                        4,
                                                                                        4,
                                                                                        0,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=64800,
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                1996,
                                                                                                4,
                                                                                                7,
                                                                                                15,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=64800,
                                                                                                ): {
                                                                                                    "America/Regina",
                                                                                                    "Canada/Saskatchewan",
                                                                                                    "Etc/GMT+6",
                                                                                                },
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=68400,
                                                                                                ): (
                                                                                                    datetime.datetime(
                                                                                                        1998,
                                                                                                        4,
                                                                                                        5,
                                                                                                        15,
                                                                                                        0,
                                                                                                    ),
                                                                                                    {
                                                                                                        datetime.timedelta(
                                                                                                            days=-1,
                                                                                                            seconds=64800,
                                                                                                        ): (
                                                                                                            datetime.datetime(
                                                                                                                2010,
                                                                                                                3,
                                                                                                                14,
                                                                                                                21,
                                                                                                                0,
                                                                                                            ),
                                                                                                            {
                                                                                                                datetime.timedelta(
                                                                                                                    days=-1,
                                                                                                                    seconds=61200,
                                                                                                                ): {
                                                                                                                    "America/Chihuahua"
                                                                                                                },
                                                                                                                datetime.timedelta(
                                                                                                                    days=-1,
                                                                                                                    seconds=64800,
                                                                                                                ): {
                                                                                                                    "America/Ciudad_Juarez",
                                                                                                                    "America/Ojinaga",
                                                                                                                },
                                                                                                            },
                                                                                                        ),
                                                                                                        datetime.timedelta(
                                                                                                            days=-1,
                                                                                                            seconds=68400,
                                                                                                        ): {
                                                                                                            "America/Mexico_City",
                                                                                                            "Mexico/General",
                                                                                                        },
                                                                                                    },
                                                                                                ),
                                                                                            },
                                                                                        ),
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=68400,
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                2010,
                                                                                                3,
                                                                                                14,
                                                                                                21,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=64800,
                                                                                                ): {
                                                                                                    "America/Monterrey"
                                                                                                },
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=68400,
                                                                                                ): {
                                                                                                    "America/Matamoros"
                                                                                                },
                                                                                            },
                                                                                        ),
                                                                                    },
                                                                                ),
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=68400,
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        2006,
                                                                                        5,
                                                                                        8,
                                                                                        0,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=64800,
                                                                                        ): {
                                                                                            "America/El_Salvador"
                                                                                        },
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=68400,
                                                                                        ): {
                                                                                            "America/Tegucigalpa"
                                                                                        },
                                                                                    },
                                                                                ),
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=68400,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1982,
                                                                                11,
                                                                                2,
                                                                                18,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=64800,
                                                                                ): {
                                                                                    "America/Merida"
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=68400,
                                                                                ): {
                                                                                    "America/Cancun"
                                                                                },
                                                                            },
                                                                        ),
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=68400,
                                                                ): {
                                                                    "America/Costa_Rica"
                                                                },
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            days=-1, seconds=68400
                                                        ): {"America/Belize"},
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=68400
                                                ): {"America/Guatemala"},
                                            },
                                        ),
                                        datetime.timedelta(days=-1, seconds=68400): {
                                            "America/Managua"
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=68400): (
                                    datetime.datetime(2006, 10, 29, 21, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=64800): {
                                            "America/Rankin_Inlet"
                                        },
                                        datetime.timedelta(days=-1, seconds=68400): {
                                            "America/Resolute"
                                        },
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=68400): (
                            datetime.datetime(1974, 1, 6, 18, 0),
                            {
                                datetime.timedelta(days=-1, seconds=64800): {
                                    "America/Rainy_River",
                                    "America/Winnipeg",
                                    "Canada/Central",
                                },
                                datetime.timedelta(days=-1, seconds=68400): (
                                    datetime.datetime(1977, 10, 31, 0, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=64800): (
                                            datetime.datetime(1991, 10, 27, 18, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=64800
                                                ): (
                                                    datetime.datetime(
                                                        2000, 10, 29, 15, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=64800
                                                        ): {
                                                            "America/Chicago",
                                                            "CST6CDT",
                                                            "US/Central",
                                                        },
                                                        datetime.timedelta(
                                                            days=-1, seconds=68400
                                                        ): {
                                                            "America/Kentucky/Monticello"
                                                        },
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=68400
                                                ): {
                                                    "America/Indiana/Knox",
                                                    "America/Knox_IN",
                                                    "US/Indiana-Starke",
                                                },
                                            },
                                        ),
                                        datetime.timedelta(days=-1, seconds=68400): {
                                            "America/Indiana/Petersburg"
                                        },
                                    },
                                ),
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=68400): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=68400): (
                    datetime.datetime(1972, 4, 30, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=68400): (
                            datetime.datetime(1973, 4, 29, 21, 0),
                            {
                                datetime.timedelta(days=-1, seconds=68400): (
                                    datetime.datetime(1973, 10, 28, 21, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=64800): {
                                            "America/Menominee"
                                        },
                                        datetime.timedelta(days=-1, seconds=68400): (
                                            datetime.datetime(1974, 1, 6, 15, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=68400
                                                ): (
                                                    datetime.datetime(
                                                        1979, 4, 29, 21, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=68400
                                                        ): (
                                                            datetime.datetime(
                                                                1983, 5, 8, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=68400,
                                                                ): (
                                                                    datetime.datetime(
                                                                        1985,
                                                                        11,
                                                                        2,
                                                                        15,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=68400,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1986,
                                                                                1,
                                                                                1,
                                                                                18,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=64800,
                                                                                ): {
                                                                                    "Pacific/Galapagos"
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=68400,
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        1992,
                                                                                        5,
                                                                                        4,
                                                                                        0,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=68400,
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                1992,
                                                                                                11,
                                                                                                28,
                                                                                                15,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=68400,
                                                                                                ): {
                                                                                                    "America/Atikokan",
                                                                                                    "America/Cayman",
                                                                                                    "America/Coral_Harbour",
                                                                                                    "America/Panama",
                                                                                                    "EST",
                                                                                                    "Etc/GMT+5",
                                                                                                },
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=72000,
                                                                                                ): {
                                                                                                    "America/Guayaquil"
                                                                                                },
                                                                                            },
                                                                                        ),
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=72000,
                                                                                        ): {
                                                                                            "America/Bogota"
                                                                                        },
                                                                                    },
                                                                                ),
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=72000,
                                                                                ): {
                                                                                    "America/Lima"
                                                                                },
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=72000,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1993,
                                                                                10,
                                                                                17,
                                                                                15,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=68400,
                                                                                ): {
                                                                                    "America/Porto_Acre",
                                                                                    "America/Rio_Branco",
                                                                                    "Brazil/Acre",
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=72000,
                                                                                ): {
                                                                                    "America/Eirunepe"
                                                                                },
                                                                            },
                                                                        ),
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=72000,
                                                                ): {
                                                                    "America/Port-au-Prince"
                                                                },
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            days=-1, seconds=72000
                                                        ): {"America/Grand_Turk"},
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=72000
                                                ): {"America/Jamaica", "Jamaica"},
                                            },
                                        ),
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=72000): {
                                    "America/Detroit",
                                    "US/Michigan",
                                },
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=72000): {
                            "America/Iqaluit",
                            "America/Pangnirtung",
                        },
                    },
                ),
                datetime.timedelta(days=-1, seconds=72000): (
                    datetime.datetime(1971, 4, 25, 15, 0),
                    {
                        datetime.timedelta(days=-1, seconds=68400): (
                            datetime.datetime(2006, 4, 2, 15, 0),
                            {
                                datetime.timedelta(days=-1, seconds=68400): (
                                    datetime.datetime(2007, 3, 12, 3, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=68400): (
                                            datetime.datetime(2007, 11, 4, 15, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=64800
                                                ): {"America/Indiana/Tell_City"},
                                                datetime.timedelta(
                                                    days=-1, seconds=68400
                                                ): {"America/Indiana/Vincennes"},
                                            },
                                        ),
                                        datetime.timedelta(days=-1, seconds=72000): {
                                            "America/Indiana/Winamac"
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=72000): {
                                    "America/Fort_Wayne",
                                    "America/Indiana/Indianapolis",
                                    "America/Indianapolis",
                                    "US/East-Indiana",
                                },
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=72000): (
                            datetime.datetime(1972, 10, 8, 12, 0),
                            {
                                datetime.timedelta(days=-1, seconds=68400): {
                                    "America/Havana",
                                    "Cuba",
                                },
                                datetime.timedelta(days=-1, seconds=72000): (
                                    datetime.datetime(1973, 4, 29, 15, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=68400): {
                                            "America/Indiana/Vevay"
                                        },
                                        datetime.timedelta(days=-1, seconds=72000): (
                                            datetime.datetime(1974, 1, 6, 18, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=68400
                                                ): (
                                                    datetime.datetime(
                                                        1974, 4, 28, 15, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=68400
                                                        ): (
                                                            datetime.datetime(
                                                                1976, 4, 26, 0, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=68400,
                                                                ): {
                                                                    "America/Indiana/Marengo"
                                                                },
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=72000,
                                                                ): {
                                                                    "America/Kentucky/Louisville",
                                                                    "America/Louisville",
                                                                },
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            days=-1, seconds=72000
                                                        ): {
                                                            "America/Montreal",
                                                            "America/Nassau",
                                                            "America/Nipigon",
                                                            "America/Thunder_Bay",
                                                            "America/Toronto",
                                                            "Canada/Eastern",
                                                        },
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=72000
                                                ): {
                                                    "America/New_York",
                                                    "EST5EDT",
                                                    "US/Eastern",
                                                },
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=70200): {"America/Santo_Domingo"},
        datetime.timedelta(days=-1, seconds=72000): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=72000): (
                    datetime.datetime(1972, 4, 30, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=72000): (
                            datetime.datetime(1972, 10, 2, 0, 0),
                            {
                                datetime.timedelta(days=-1, seconds=72000): (
                                    datetime.datetime(1974, 4, 28, 21, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=72000): (
                                            datetime.datetime(1977, 6, 12, 18, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=72000
                                                ): (
                                                    datetime.datetime(
                                                        1980, 4, 6, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=72000
                                                        ): (
                                                            datetime.datetime(
                                                                1980, 5, 2, 0, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=72000,
                                                                ): (
                                                                    datetime.datetime(
                                                                        1983, 5, 2, 0, 0
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=72000,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1985,
                                                                                11,
                                                                                2,
                                                                                18,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=72000,
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        1991,
                                                                                        3,
                                                                                        31,
                                                                                        18,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=72000,
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                2007,
                                                                                                12,
                                                                                                10,
                                                                                                0,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=70200,
                                                                                                ): {
                                                                                                    "America/Caracas"
                                                                                                },
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=72000,
                                                                                                ): {
                                                                                                    "America/Anguilla",
                                                                                                    "America/Antigua",
                                                                                                    "America/Aruba",
                                                                                                    "America/Blanc-Sablon",
                                                                                                    "America/Curacao",
                                                                                                    "America/Dominica",
                                                                                                    "America/Grenada",
                                                                                                    "America/Guadeloupe",
                                                                                                    "America/Kralendijk",
                                                                                                    "America/La_Paz",
                                                                                                    "America/Lower_Princes",
                                                                                                    "America/Marigot",
                                                                                                    "America/Montserrat",
                                                                                                    "America/Port_of_Spain",
                                                                                                    "America/Puerto_Rico",
                                                                                                    "America/St_Barthelemy",
                                                                                                    "America/St_Kitts",
                                                                                                    "America/St_Lucia",
                                                                                                    "America/St_Thomas",
                                                                                                    "America/St_Vincent",
                                                                                                    "America/Tortola",
                                                                                                    "America/Virgin",
                                                                                                    "Etc/GMT+4",
                                                                                                },
                                                                                            },
                                                                                        ),
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=75600,
                                                                                        ): {
                                                                                            "America/Thule"
                                                                                        },
                                                                                    },
                                                                                ),
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=75600,
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        1988,
                                                                                        10,
                                                                                        16,
                                                                                        15,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=72000,
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                1993,
                                                                                                10,
                                                                                                17,
                                                                                                15,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=72000,
                                                                                                ): (
                                                                                                    datetime.datetime(
                                                                                                        1999,
                                                                                                        10,
                                                                                                        3,
                                                                                                        18,
                                                                                                        0,
                                                                                                    ),
                                                                                                    {
                                                                                                        datetime.timedelta(
                                                                                                            days=-1,
                                                                                                            seconds=72000,
                                                                                                        ): (
                                                                                                            datetime.datetime(
                                                                                                                2008,
                                                                                                                6,
                                                                                                                24,
                                                                                                                15,
                                                                                                                0,
                                                                                                            ),
                                                                                                            {
                                                                                                                datetime.timedelta(
                                                                                                                    days=-1,
                                                                                                                    seconds=72000,
                                                                                                                ): {
                                                                                                                    "America/Porto_Velho"
                                                                                                                },
                                                                                                                datetime.timedelta(
                                                                                                                    days=-1,
                                                                                                                    seconds=75600,
                                                                                                                ): {
                                                                                                                    "America/Santarem"
                                                                                                                },
                                                                                                            },
                                                                                                        ),
                                                                                                        datetime.timedelta(
                                                                                                            days=-1,
                                                                                                            seconds=75600,
                                                                                                        ): {
                                                                                                            "America/Boa_Vista"
                                                                                                        },
                                                                                                    },
                                                                                                ),
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=75600,
                                                                                                ): {
                                                                                                    "America/Manaus",
                                                                                                    "Brazil/West",
                                                                                                },
                                                                                            },
                                                                                        ),
                                                                                        datetime.timedelta(
                                                                                            days=-1,
                                                                                            seconds=75600,
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                2003,
                                                                                                10,
                                                                                                19,
                                                                                                21,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=72000,
                                                                                                ): {
                                                                                                    "America/Cuiaba"
                                                                                                },
                                                                                                datetime.timedelta(
                                                                                                    days=-1,
                                                                                                    seconds=75600,
                                                                                                ): {
                                                                                                    "America/Campo_Grande"
                                                                                                },
                                                                                            },
                                                                                        ),
                                                                                    },
                                                                                ),
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=75600,
                                                                        ): {
                                                                            "Atlantic/Stanley"
                                                                        },
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=75600,
                                                                ): {"America/Miquelon"},
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            days=-1, seconds=75600
                                                        ): {"America/Martinique"},
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=75600
                                                ): {"America/Barbados"},
                                            },
                                        ),
                                        datetime.timedelta(days=-1, seconds=75600): {
                                            "Atlantic/Bermuda"
                                        },
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=75600): {
                                    "America/Asuncion"
                                },
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=75600): {
                            "America/Glace_Bay"
                        },
                    },
                ),
                datetime.timedelta(days=-1, seconds=75600): (
                    datetime.datetime(1973, 4, 30, 0, 0),
                    {
                        datetime.timedelta(days=-1, seconds=72000): {"America/Moncton"},
                        datetime.timedelta(days=-1, seconds=75600): (
                            datetime.datetime(1988, 4, 3, 15, 0),
                            {
                                datetime.timedelta(days=-1, seconds=75600): {
                                    "America/Halifax",
                                    "Canada/Atlantic",
                                },
                                datetime.timedelta(days=-1, seconds=79200): {
                                    "America/Goose_Bay"
                                },
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=72900): {"America/Guyana"},
        datetime.timedelta(days=-1, seconds=73800): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=73800): {"America/Paramaribo"},
                datetime.timedelta(days=-1, seconds=77400): {
                    "America/St_Johns",
                    "Canada/Newfoundland",
                },
            },
        ),
        datetime.timedelta(days=-1, seconds=75600): (
            datetime.datetime(1970, 3, 29, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=72000): (
                    datetime.datetime(2017, 5, 14, 18, 0),
                    {
                        datetime.timedelta(days=-1, seconds=72000): {
                            "America/Santiago",
                            "Chile/Continental",
                        },
                        datetime.timedelta(days=-1, seconds=75600): {
                            "America/Punta_Arenas"
                        },
                    },
                ),
                datetime.timedelta(days=-1, seconds=75600): (
                    datetime.datetime(1970, 4, 25, 18, 0),
                    {
                        datetime.timedelta(days=-1, seconds=75600): (
                            datetime.datetime(1974, 1, 23, 21, 0),
                            {
                                datetime.timedelta(days=-1, seconds=75600): (
                                    datetime.datetime(1980, 4, 7, 0, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=75600): (
                                            datetime.datetime(1985, 11, 3, 0, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=75600
                                                ): {"America/Cayenne", "Etc/GMT+3"},
                                                datetime.timedelta(
                                                    days=-1, seconds=79200
                                                ): (
                                                    datetime.datetime(
                                                        1988, 10, 16, 15, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=75600
                                                        ): {"America/Belem"},
                                                        datetime.timedelta(
                                                            days=-1, seconds=79200
                                                        ): (
                                                            datetime.datetime(
                                                                1990, 10, 22, 0, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=75600,
                                                                ): (
                                                                    datetime.datetime(
                                                                        1995,
                                                                        10,
                                                                        15,
                                                                        15,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=75600,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                2000,
                                                                                10,
                                                                                15,
                                                                                12,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=75600,
                                                                                ): {
                                                                                    "America/Recife"
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=79200,
                                                                                ): {
                                                                                    "America/Fortaleza"
                                                                                },
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=79200,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1996,
                                                                                10,
                                                                                6,
                                                                                18,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=75600,
                                                                                ): {
                                                                                    "America/Maceio"
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=79200,
                                                                                ): {
                                                                                    "America/Araguaina"
                                                                                },
                                                                            },
                                                                        ),
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=79200,
                                                                ): (
                                                                    datetime.datetime(
                                                                        2003,
                                                                        10,
                                                                        19,
                                                                        21,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=75600,
                                                                        ): {
                                                                            "America/Bahia"
                                                                        },
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=79200,
                                                                        ): {
                                                                            "America/Sao_Paulo",
                                                                            "Brazil/East",
                                                                        },
                                                                    },
                                                                ),
                                                            },
                                                        ),
                                                    },
                                                ),
                                            },
                                        ),
                                        datetime.timedelta(days=-1, seconds=79200): (
                                            datetime.datetime(1996, 1, 2, 0, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=75600
                                                ): {"America/Godthab", "America/Nuuk"},
                                                datetime.timedelta(0): {
                                                    "America/Danmarkshavn"
                                                },
                                            },
                                        ),
                                    },
                                ),
                                datetime.timedelta(days=-1, seconds=79200): (
                                    datetime.datetime(1982, 5, 1, 21, 0),
                                    {
                                        datetime.timedelta(days=-1, seconds=72000): {
                                            "Antarctica/Palmer"
                                        },
                                        datetime.timedelta(days=-1, seconds=75600): (
                                            datetime.datetime(1990, 3, 4, 21, 0),
                                            {
                                                datetime.timedelta(
                                                    days=-1, seconds=72000
                                                ): (
                                                    datetime.datetime(
                                                        1990, 10, 16, 0, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=72000
                                                        ): {
                                                            "America/Argentina/Jujuy",
                                                            "America/Jujuy",
                                                        },
                                                        datetime.timedelta(
                                                            days=-1, seconds=75600
                                                        ): {
                                                            "America/Argentina/Mendoza",
                                                            "America/Mendoza",
                                                        },
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=75600
                                                ): (
                                                    datetime.datetime(
                                                        1991, 3, 1, 15, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            days=-1, seconds=72000
                                                        ): (
                                                            datetime.datetime(
                                                                2004, 6, 20, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=72000,
                                                                ): {
                                                                    "America/Argentina/San_Juan"
                                                                },
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=75600,
                                                                ): {
                                                                    "America/Argentina/La_Rioja"
                                                                },
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            days=-1, seconds=79200
                                                        ): (
                                                            datetime.datetime(
                                                                1991, 3, 4, 0, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=72000,
                                                                ): (
                                                                    datetime.datetime(
                                                                        2004,
                                                                        6,
                                                                        1,
                                                                        12,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=72000,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                2004,
                                                                                6,
                                                                                14,
                                                                                0,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=72000,
                                                                                ): {
                                                                                    "America/Argentina/Catamarca",
                                                                                    "America/Argentina/ComodRivadavia",
                                                                                    "America/Catamarca",
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=75600,
                                                                                ): {
                                                                                    "America/Argentina/Tucuman"
                                                                                },
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=75600,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                2008,
                                                                                10,
                                                                                19,
                                                                                15,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=75600,
                                                                                ): {
                                                                                    "America/Argentina/Salta"
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=79200,
                                                                                ): {
                                                                                    "America/Argentina/Cordoba",
                                                                                    "America/Cordoba",
                                                                                    "America/Rosario",
                                                                                },
                                                                            },
                                                                        ),
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    days=-1,
                                                                    seconds=75600,
                                                                ): (
                                                                    datetime.datetime(
                                                                        2004,
                                                                        5,
                                                                        30,
                                                                        15,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=72000,
                                                                        ): {
                                                                            "America/Argentina/Ushuaia"
                                                                        },
                                                                        datetime.timedelta(
                                                                            days=-1,
                                                                            seconds=75600,
                                                                        ): (
                                                                            datetime.datetime(
                                                                                2004,
                                                                                6,
                                                                                1,
                                                                                12,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=72000,
                                                                                ): {
                                                                                    "America/Argentina/Rio_Gallegos"
                                                                                },
                                                                                datetime.timedelta(
                                                                                    days=-1,
                                                                                    seconds=75600,
                                                                                ): {
                                                                                    "America/Argentina/Buenos_Aires",
                                                                                    "America/Buenos_Aires",
                                                                                },
                                                                            },
                                                                        ),
                                                                    },
                                                                ),
                                                            },
                                                        ),
                                                    },
                                                ),
                                                datetime.timedelta(
                                                    days=-1, seconds=79200
                                                ): {"America/Argentina/San_Luis"},
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=79200): {
                            "America/Montevideo"
                        },
                    },
                ),
            },
        ),
        datetime.timedelta(days=-1, seconds=79200): (
            datetime.datetime(1975, 11, 25, 18, 0),
            {
                datetime.timedelta(days=-1, seconds=79200): (
                    datetime.datetime(1980, 4, 6, 21, 0),
                    {
                        datetime.timedelta(days=-1, seconds=79200): (
                            datetime.datetime(1985, 11, 2, 21, 0),
                            {
                                datetime.timedelta(days=-1, seconds=79200): {
                                    "Atlantic/South_Georgia",
                                    "Etc/GMT+2",
                                },
                                datetime.timedelta(days=-1, seconds=82800): {
                                    "America/Noronha",
                                    "Brazil/DeNoronha",
                                },
                            },
                        ),
                        datetime.timedelta(days=-1, seconds=82800): {
                            "America/Scoresbysund"
                        },
                    },
                ),
                datetime.timedelta(days=-1, seconds=82800): {"Atlantic/Cape_Verde"},
            },
        ),
        datetime.timedelta(days=-1, seconds=82800): (
            datetime.datetime(1975, 1, 1, 15, 0),
            {
                datetime.timedelta(days=-1, seconds=82800): (
                    datetime.datetime(1976, 4, 15, 0, 0),
                    {
                        datetime.timedelta(days=-1, seconds=82800): (
                            datetime.datetime(1982, 3, 29, 0, 0),
                            {
                                datetime.timedelta(days=-1, seconds=82800): {
                                    "Etc/GMT+1"
                                },
                                datetime.timedelta(0): {"Atlantic/Azores"},
                            },
                        ),
                        datetime.timedelta(0): {"Africa/El_Aaiun"},
                    },
                ),
                datetime.timedelta(0): {"Africa/Bissau"},
            },
        ),
        datetime.timedelta(days=-1, seconds=83730): {"Africa/Monrovia"},
        datetime.timedelta(days=-1, seconds=83760): {"Africa/Monrovia"},
        datetime.timedelta(0): (
            datetime.datetime(1971, 4, 26, 12, 0),
            {
                datetime.timedelta(0): (
                    datetime.datetime(1974, 6, 25, 0, 0),
                    {
                        datetime.timedelta(0): (
                            datetime.datetime(1976, 12, 1, 15, 0),
                            {
                                datetime.timedelta(days=-1, seconds=75600): {
                                    "Antarctica/Rothera"
                                },
                                datetime.timedelta(0): (
                                    datetime.datetime(1977, 4, 4, 0, 0),
                                    {
                                        datetime.timedelta(0): (
                                            datetime.datetime(1980, 4, 6, 15, 0),
                                            {
                                                datetime.timedelta(0): (
                                                    datetime.datetime(
                                                        1981, 3, 29, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(0): (
                                                            datetime.datetime(
                                                                1982, 4, 4, 15, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(0): (
                                                                    datetime.datetime(
                                                                        2005,
                                                                        3,
                                                                        27,
                                                                        15,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            0
                                                                        ): (
                                                                            datetime.datetime(
                                                                                2018,
                                                                                1,
                                                                                1,
                                                                                18,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    0
                                                                                ): {
                                                                                    "Africa/Abidjan",
                                                                                    "Africa/Accra",
                                                                                    "Africa/Bamako",
                                                                                    "Africa/Banjul",
                                                                                    "Africa/Conakry",
                                                                                    "Africa/Dakar",
                                                                                    "Africa/Freetown",
                                                                                    "Africa/Lome",
                                                                                    "Africa/Nouakchott",
                                                                                    "Africa/Ouagadougou",
                                                                                    "Africa/Timbuktu",
                                                                                    "Atlantic/Reykjavik",
                                                                                    "Atlantic/St_Helena",
                                                                                    "Etc/GMT",
                                                                                    "Etc/GMT+0",
                                                                                    "Etc/GMT-0",
                                                                                    "Etc/GMT0",
                                                                                    "Etc/Greenwich",
                                                                                    "Etc/UCT",
                                                                                    "Etc/UTC",
                                                                                    "Etc/Universal",
                                                                                    "Etc/Zulu",
                                                                                    "GMT",
                                                                                    "GMT+0",
                                                                                    "GMT-0",
                                                                                    "GMT0",
                                                                                    "Greenwich",
                                                                                    "Iceland",
                                                                                    "UCT",
                                                                                    "UTC",
                                                                                    "Universal",
                                                                                    "Zulu",
                                                                                },
                                                                                datetime.timedelta(
                                                                                    seconds=3600
                                                                                ): {
                                                                                    "Africa/Sao_Tome"
                                                                                },
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            seconds=7200
                                                                        ): {
                                                                            "Antarctica/Troll"
                                                                        },
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    seconds=3600
                                                                ): {"Atlantic/Madeira"},
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            seconds=3600
                                                        ): {
                                                            "Atlantic/Faeroe",
                                                            "Atlantic/Faroe",
                                                        },
                                                    },
                                                ),
                                                datetime.timedelta(seconds=3600): {
                                                    "Atlantic/Canary"
                                                },
                                            },
                                        ),
                                        datetime.timedelta(seconds=3600): {"WET"},
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(seconds=3600): (
                            datetime.datetime(1986, 1, 1, 12, 0),
                            {
                                datetime.timedelta(0): {"Africa/Casablanca"},
                                datetime.timedelta(seconds=3600): {"Africa/Ceuta"},
                            },
                        ),
                    },
                ),
                datetime.timedelta(seconds=3600): {"Africa/Algiers"},
            },
        ),
        datetime.timedelta(seconds=3600): (
            datetime.datetime(1970, 6, 1, 0, 0),
            {
                datetime.timedelta(seconds=3600): (
                    datetime.datetime(1971, 11, 1, 0, 0),
                    {
                        datetime.timedelta(0): {
                            "Eire",
                            "Europe/Belfast",
                            "Europe/Dublin",
                            "Europe/Guernsey",
                            "Europe/Isle_of_Man",
                            "Europe/Jersey",
                            "Europe/London",
                            "GB",
                            "GB-Eire",
                        },
                        datetime.timedelta(seconds=3600): (
                            datetime.datetime(1974, 4, 14, 15, 0),
                            {
                                datetime.timedelta(seconds=3600): (
                                    datetime.datetime(1974, 5, 4, 21, 0),
                                    {
                                        datetime.timedelta(seconds=3600): (
                                            datetime.datetime(1976, 3, 28, 21, 0),
                                            {
                                                datetime.timedelta(seconds=3600): (
                                                    datetime.datetime(
                                                        1976, 9, 26, 21, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(0): (
                                                            datetime.datetime(
                                                                1980, 3, 30, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(0): {
                                                                    "Europe/Lisbon",
                                                                    "Portugal",
                                                                    "WET",
                                                                },
                                                                datetime.timedelta(
                                                                    seconds=3600
                                                                ): {"Portugal"},
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            seconds=3600
                                                        ): (
                                                            datetime.datetime(
                                                                1977, 4, 3, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    seconds=3600
                                                                ): (
                                                                    datetime.datetime(
                                                                        1977,
                                                                        4,
                                                                        30,
                                                                        21,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            seconds=3600
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1979,
                                                                                4,
                                                                                1,
                                                                                18,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    seconds=3600
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        1979,
                                                                                        10,
                                                                                        15,
                                                                                        0,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            seconds=3600
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                1980,
                                                                                                4,
                                                                                                6,
                                                                                                15,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    seconds=3600
                                                                                                ): (
                                                                                                    datetime.datetime(
                                                                                                        1981,
                                                                                                        3,
                                                                                                        29,
                                                                                                        18,
                                                                                                        0,
                                                                                                    ),
                                                                                                    {
                                                                                                        datetime.timedelta(
                                                                                                            seconds=3600
                                                                                                        ): (
                                                                                                            datetime.datetime(
                                                                                                                1982,
                                                                                                                3,
                                                                                                                28,
                                                                                                                18,
                                                                                                                0,
                                                                                                            ),
                                                                                                            {
                                                                                                                datetime.timedelta(
                                                                                                                    seconds=3600
                                                                                                                ): (
                                                                                                                    datetime.datetime(
                                                                                                                        1983,
                                                                                                                        3,
                                                                                                                        27,
                                                                                                                        18,
                                                                                                                        0,
                                                                                                                    ),
                                                                                                                    {
                                                                                                                        datetime.timedelta(
                                                                                                                            seconds=3600
                                                                                                                        ): (
                                                                                                                            datetime.datetime(
                                                                                                                                1985,
                                                                                                                                4,
                                                                                                                                1,
                                                                                                                                0,
                                                                                                                                0,
                                                                                                                            ),
                                                                                                                            {
                                                                                                                                datetime.timedelta(
                                                                                                                                    seconds=3600
                                                                                                                                ): {
                                                                                                                                    "Africa/Bangui",
                                                                                                                                    "Africa/Brazzaville",
                                                                                                                                    "Africa/Douala",
                                                                                                                                    "Africa/Kinshasa",
                                                                                                                                    "Africa/Lagos",
                                                                                                                                    "Africa/Libreville",
                                                                                                                                    "Africa/Luanda",
                                                                                                                                    "Africa/Malabo",
                                                                                                                                    "Africa/Niamey",
                                                                                                                                    "Africa/Porto-Novo",
                                                                                                                                    "Etc/GMT-1",
                                                                                                                                },
                                                                                                                                datetime.timedelta(
                                                                                                                                    seconds=7200
                                                                                                                                ): {
                                                                                                                                    "Europe/Andorra"
                                                                                                                                },
                                                                                                                            },
                                                                                                                        ),
                                                                                                                        datetime.timedelta(
                                                                                                                            seconds=7200
                                                                                                                        ): {
                                                                                                                            "Europe/Belgrade",
                                                                                                                            "Europe/Ljubljana",
                                                                                                                            "Europe/Podgorica",
                                                                                                                            "Europe/Sarajevo",
                                                                                                                            "Europe/Skopje",
                                                                                                                            "Europe/Zagreb",
                                                                                                                        },
                                                                                                                    },
                                                                                                                ),
                                                                                                                datetime.timedelta(
                                                                                                                    seconds=7200
                                                                                                                ): {
                                                                                                                    "Europe/Gibraltar"
                                                                                                                },
                                                                                                            },
                                                                                                        ),
                                                                                                        datetime.timedelta(
                                                                                                            seconds=7200
                                                                                                        ): {
                                                                                                            "Europe/Busingen",
                                                                                                            "Europe/Vaduz",
                                                                                                            "Europe/Zurich",
                                                                                                        },
                                                                                                    },
                                                                                                ),
                                                                                                datetime.timedelta(
                                                                                                    seconds=7200
                                                                                                ): {
                                                                                                    "Arctic/Longyearbyen",
                                                                                                    "Atlantic/Jan_Mayen",
                                                                                                    "Europe/Berlin",
                                                                                                    "Europe/Budapest",
                                                                                                    "Europe/Copenhagen",
                                                                                                    "Europe/Oslo",
                                                                                                    "Europe/Stockholm",
                                                                                                    "Europe/Vienna",
                                                                                                },
                                                                                            },
                                                                                        ),
                                                                                        datetime.timedelta(
                                                                                            seconds=7200
                                                                                        ): {
                                                                                            "Africa/Ndjamena"
                                                                                        },
                                                                                    },
                                                                                ),
                                                                                datetime.timedelta(
                                                                                    seconds=7200
                                                                                ): {
                                                                                    "Europe/Bratislava",
                                                                                    "Europe/Prague",
                                                                                },
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            seconds=7200
                                                                        ): {
                                                                            "Africa/Tunis"
                                                                        },
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    seconds=7200
                                                                ): {
                                                                    "CET",
                                                                    "Europe/Amsterdam",
                                                                    "Europe/Brussels",
                                                                    "Europe/Luxembourg",
                                                                    "Europe/Warsaw",
                                                                    "MET",
                                                                    "Poland",
                                                                },
                                                            },
                                                        ),
                                                    },
                                                ),
                                                datetime.timedelta(seconds=7200): {
                                                    "Europe/Monaco",
                                                    "Europe/Paris",
                                                },
                                            },
                                        ),
                                        datetime.timedelta(seconds=7200): {
                                            "Europe/Tirane"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=7200): {"Europe/Madrid"},
                            },
                        ),
                    },
                ),
                datetime.timedelta(seconds=7200): (
                    datetime.datetime(1973, 3, 31, 18, 0),
                    {
                        datetime.timedelta(seconds=3600): {
                            "Europe/Rome",
                            "Europe/San_Marino",
                            "Europe/Vatican",
                        },
                        datetime.timedelta(seconds=7200): {"Europe/Malta"},
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=7200): (
            datetime.datetime(1970, 5, 1, 15, 0),
            {
                datetime.timedelta(seconds=7200): (
                    datetime.datetime(1972, 6, 23, 0, 0),
                    {
                        datetime.timedelta(seconds=7200): (
                            datetime.datetime(1973, 6, 3, 15, 0),
                            {
                                datetime.timedelta(seconds=7200): (
                                    datetime.datetime(1973, 6, 6, 21, 0),
                                    {
                                        datetime.timedelta(seconds=7200): (
                                            datetime.datetime(1974, 7, 8, 0, 0),
                                            {
                                                datetime.timedelta(seconds=7200): (
                                                    datetime.datetime(
                                                        1975, 4, 13, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=7200
                                                        ): (
                                                            datetime.datetime(
                                                                1977, 4, 3, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    seconds=7200
                                                                ): (
                                                                    datetime.datetime(
                                                                        1979,
                                                                        4,
                                                                        1,
                                                                        15,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            seconds=7200
                                                                        ): (
                                                                            datetime.datetime(
                                                                                1979,
                                                                                5,
                                                                                27,
                                                                                15,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    seconds=7200
                                                                                ): (
                                                                                    datetime.datetime(
                                                                                        1981,
                                                                                        3,
                                                                                        29,
                                                                                        15,
                                                                                        0,
                                                                                    ),
                                                                                    {
                                                                                        datetime.timedelta(
                                                                                            seconds=7200
                                                                                        ): (
                                                                                            datetime.datetime(
                                                                                                1982,
                                                                                                1,
                                                                                                1,
                                                                                                21,
                                                                                                0,
                                                                                            ),
                                                                                            {
                                                                                                datetime.timedelta(
                                                                                                    seconds=3600
                                                                                                ): {
                                                                                                    "Africa/Tripoli",
                                                                                                    "Libya",
                                                                                                },
                                                                                                datetime.timedelta(
                                                                                                    seconds=7200
                                                                                                ): (
                                                                                                    datetime.datetime(
                                                                                                        1994,
                                                                                                        3,
                                                                                                        21,
                                                                                                        18,
                                                                                                        0,
                                                                                                    ),
                                                                                                    {
                                                                                                        datetime.timedelta(
                                                                                                            seconds=3600
                                                                                                        ): {
                                                                                                            "Africa/Windhoek"
                                                                                                        },
                                                                                                        datetime.timedelta(
                                                                                                            seconds=7200
                                                                                                        ): {
                                                                                                            "Africa/Blantyre",
                                                                                                            "Africa/Bujumbura",
                                                                                                            "Africa/Gaborone",
                                                                                                            "Africa/Harare",
                                                                                                            "Africa/Johannesburg",
                                                                                                            "Africa/Kigali",
                                                                                                            "Africa/Lubumbashi",
                                                                                                            "Africa/Lusaka",
                                                                                                            "Africa/Maputo",
                                                                                                            "Africa/Maseru",
                                                                                                            "Africa/Mbabane",
                                                                                                            "Etc/GMT-2",
                                                                                                        },
                                                                                                    },
                                                                                                ),
                                                                                            },
                                                                                        ),
                                                                                        datetime.timedelta(
                                                                                            seconds=10800
                                                                                        ): {
                                                                                            "Europe/Helsinki",
                                                                                            "Europe/Mariehamn",
                                                                                        },
                                                                                    },
                                                                                ),
                                                                                datetime.timedelta(
                                                                                    seconds=10800
                                                                                ): {
                                                                                    "Europe/Bucharest"
                                                                                },
                                                                            },
                                                                        ),
                                                                        datetime.timedelta(
                                                                            seconds=10800
                                                                        ): {
                                                                            "Europe/Sofia"
                                                                        },
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    seconds=10800
                                                                ): {"EET"},
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            seconds=10800
                                                        ): (
                                                            datetime.datetime(
                                                                1975, 10, 12, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    seconds=7200
                                                                ): (
                                                                    datetime.datetime(
                                                                        2016,
                                                                        10,
                                                                        31,
                                                                        3,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            seconds=7200
                                                                        ): {
                                                                            "Asia/Nicosia",
                                                                            "Europe/Nicosia",
                                                                        },
                                                                        datetime.timedelta(
                                                                            seconds=10800
                                                                        ): {
                                                                            "Asia/Famagusta"
                                                                        },
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    seconds=10800
                                                                ): {
                                                                    "EET",
                                                                    "Europe/Athens",
                                                                },
                                                            },
                                                        ),
                                                    },
                                                ),
                                                datetime.timedelta(seconds=10800): (
                                                    datetime.datetime(
                                                        1996, 3, 15, 21, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=7200
                                                        ): (
                                                            datetime.datetime(
                                                                2008, 8, 29, 18, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    seconds=7200
                                                                ): {"Asia/Gaza"},
                                                                datetime.timedelta(
                                                                    seconds=10800
                                                                ): {"Asia/Hebron"},
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            seconds=10800
                                                        ): {
                                                            "Asia/Jerusalem",
                                                            "Asia/Tel_Aviv",
                                                            "Israel",
                                                        },
                                                    },
                                                ),
                                            },
                                        ),
                                        datetime.timedelta(seconds=10800): {
                                            "Asia/Amman"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=10800): {
                                    "Asia/Istanbul",
                                    "Europe/Istanbul",
                                    "Turkey",
                                },
                            },
                        ),
                        datetime.timedelta(seconds=10800): {"Asia/Beirut"},
                    },
                ),
                datetime.timedelta(seconds=10800): (
                    datetime.datetime(1970, 10, 1, 18, 0),
                    {
                        datetime.timedelta(seconds=7200): (
                            datetime.datetime(1977, 9, 2, 0, 0),
                            {
                                datetime.timedelta(seconds=7200): {"Asia/Damascus"},
                                datetime.timedelta(seconds=10800): {
                                    "Africa/Cairo",
                                    "Egypt",
                                },
                            },
                        ),
                        datetime.timedelta(seconds=10800): (
                            datetime.datetime(2017, 11, 1, 18, 0),
                            {
                                datetime.timedelta(seconds=7200): {"Africa/Khartoum"},
                                datetime.timedelta(seconds=10800): {"Africa/Juba"},
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=10800): (
            datetime.datetime(1981, 4, 1, 15, 0),
            {
                datetime.timedelta(seconds=10800): (
                    datetime.datetime(1982, 5, 1, 18, 0),
                    {
                        datetime.timedelta(seconds=10800): {
                            "Africa/Addis_Ababa",
                            "Africa/Asmara",
                            "Africa/Asmera",
                            "Africa/Dar_es_Salaam",
                            "Africa/Djibouti",
                            "Africa/Kampala",
                            "Africa/Mogadishu",
                            "Africa/Nairobi",
                            "Antarctica/Syowa",
                            "Asia/Aden",
                            "Asia/Kuwait",
                            "Asia/Riyadh",
                            "Etc/GMT-3",
                            "Indian/Antananarivo",
                            "Indian/Comoro",
                            "Indian/Mayotte",
                        },
                        datetime.timedelta(seconds=14400): {"Asia/Baghdad"},
                    },
                ),
                datetime.timedelta(seconds=14400): (
                    datetime.datetime(1989, 3, 26, 21, 0),
                    {
                        datetime.timedelta(seconds=10800): (
                            datetime.datetime(1996, 9, 29, 15, 0),
                            {
                                datetime.timedelta(seconds=7200): {"Europe/Riga"},
                                datetime.timedelta(seconds=10800): (
                                    datetime.datetime(1998, 3, 29, 15, 0),
                                    {
                                        datetime.timedelta(seconds=7200): {
                                            "Europe/Vilnius"
                                        },
                                        datetime.timedelta(seconds=10800): (
                                            datetime.datetime(2000, 3, 26, 21, 0),
                                            {
                                                datetime.timedelta(seconds=7200): {
                                                    "Europe/Tallinn"
                                                },
                                                datetime.timedelta(seconds=10800): {
                                                    "Europe/Kaliningrad"
                                                },
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(seconds=14400): (
                            datetime.datetime(1990, 3, 25, 21, 0),
                            {
                                datetime.timedelta(seconds=10800): (
                                    datetime.datetime(1990, 7, 2, 0, 0),
                                    {
                                        datetime.timedelta(seconds=7200): {
                                            "Europe/Simferopol"
                                        },
                                        datetime.timedelta(seconds=10800): {
                                            "Europe/Minsk"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=14400): (
                                    datetime.datetime(1990, 5, 6, 15, 0),
                                    {
                                        datetime.timedelta(seconds=10800): {
                                            "Europe/Chisinau",
                                            "Europe/Tiraspol",
                                        },
                                        datetime.timedelta(seconds=14400): (
                                            datetime.datetime(1990, 7, 1, 15, 0),
                                            {
                                                datetime.timedelta(seconds=10800): {
                                                    "Europe/Kiev",
                                                    "Europe/Kyiv",
                                                    "Europe/Uzhgorod",
                                                    "Europe/Zaporozhye",
                                                },
                                                datetime.timedelta(seconds=14400): {
                                                    "Europe/Moscow",
                                                    "W-SU",
                                                },
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=12600): {"Iran", "Asia/Tehran"},
        datetime.timedelta(seconds=14400): (
            datetime.datetime(1972, 6, 1, 21, 0),
            {
                datetime.timedelta(seconds=10800): {"Asia/Bahrain", "Asia/Qatar"},
                datetime.timedelta(seconds=14400): (
                    datetime.datetime(1981, 4, 1, 15, 0),
                    {
                        datetime.timedelta(seconds=14400): (
                            datetime.datetime(1982, 10, 11, 0, 0),
                            {
                                datetime.timedelta(seconds=14400): {
                                    "Asia/Dubai",
                                    "Asia/Muscat",
                                    "Etc/GMT-4",
                                    "Indian/Mahe",
                                    "Indian/Reunion",
                                },
                                datetime.timedelta(seconds=18000): {"Indian/Mauritius"},
                            },
                        ),
                        datetime.timedelta(seconds=18000): (
                            datetime.datetime(1988, 3, 27, 21, 0),
                            {
                                datetime.timedelta(seconds=14400): (
                                    datetime.datetime(2016, 12, 4, 18, 0),
                                    {
                                        datetime.timedelta(seconds=10800): {
                                            "Europe/Volgograd"
                                        },
                                        datetime.timedelta(seconds=14400): {
                                            "Europe/Saratov"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=18000): (
                                    datetime.datetime(1989, 3, 26, 21, 0),
                                    {
                                        datetime.timedelta(seconds=14400): (
                                            datetime.datetime(1991, 3, 31, 18, 0),
                                            {
                                                datetime.timedelta(seconds=10800): (
                                                    datetime.datetime(
                                                        1991, 9, 29, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=7200
                                                        ): {"Europe/Ulyanovsk"},
                                                        datetime.timedelta(
                                                            seconds=10800
                                                        ): {"Europe/Samara"},
                                                    },
                                                ),
                                                datetime.timedelta(seconds=14400): (
                                                    datetime.datetime(
                                                        2016, 3, 27, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=10800
                                                        ): {"Europe/Kirov"},
                                                        datetime.timedelta(
                                                            seconds=14400
                                                        ): {"Europe/Astrakhan"},
                                                    },
                                                ),
                                            },
                                        ),
                                        datetime.timedelta(seconds=18000): (
                                            datetime.datetime(1992, 9, 27, 18, 0),
                                            {
                                                datetime.timedelta(seconds=10800): (
                                                    datetime.datetime(
                                                        1994, 9, 25, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=10800
                                                        ): {"Asia/Yerevan"},
                                                        datetime.timedelta(
                                                            seconds=14400
                                                        ): {"Asia/Tbilisi"},
                                                    },
                                                ),
                                                datetime.timedelta(seconds=14400): {
                                                    "Asia/Baku"
                                                },
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=16200): {"Asia/Kabul"},
        datetime.timedelta(seconds=18000): (
            datetime.datetime(1981, 4, 1, 15, 0),
            {
                datetime.timedelta(seconds=18000): (
                    datetime.datetime(1981, 10, 2, 0, 0),
                    {
                        datetime.timedelta(seconds=18000): (
                            datetime.datetime(1996, 1, 1, 21, 0),
                            {
                                datetime.timedelta(seconds=18000): (
                                    datetime.datetime(2002, 4, 8, 0, 0),
                                    {
                                        datetime.timedelta(seconds=18000): {
                                            "Etc/GMT-5",
                                            "Indian/Kerguelen",
                                            "Indian/Maldives",
                                        },
                                        datetime.timedelta(seconds=21600): {
                                            "Asia/Karachi"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=21600): {"Indian/Chagos"},
                            },
                        ),
                        datetime.timedelta(seconds=21600): (
                            datetime.datetime(1994, 9, 26, 3, 0),
                            {
                                datetime.timedelta(seconds=14400): {"Asia/Aqtau"},
                                datetime.timedelta(seconds=18000): {"Asia/Atyrau"},
                            },
                        ),
                    },
                ),
                datetime.timedelta(seconds=21600): (
                    datetime.datetime(1981, 10, 1, 12, 0),
                    {
                        datetime.timedelta(seconds=18000): (
                            datetime.datetime(1992, 3, 29, 18, 0),
                            {
                                datetime.timedelta(seconds=18000): {
                                    "Asia/Ashgabat",
                                    "Asia/Ashkhabad",
                                },
                                datetime.timedelta(seconds=21600): {
                                    "Asia/Yekaterinburg"
                                },
                            },
                        ),
                        datetime.timedelta(seconds=21600): (
                            datetime.datetime(1989, 3, 26, 15, 0),
                            {
                                datetime.timedelta(seconds=18000): {"Asia/Oral"},
                                datetime.timedelta(seconds=21600): (
                                    datetime.datetime(1991, 4, 1, 0, 0),
                                    {
                                        datetime.timedelta(seconds=18000): (
                                            datetime.datetime(1991, 9, 30, 0, 0),
                                            {
                                                datetime.timedelta(seconds=14400): (
                                                    datetime.datetime(
                                                        2004, 10, 31, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=18000
                                                        ): {"Asia/Aqtobe"},
                                                        datetime.timedelta(
                                                            seconds=21600
                                                        ): {"Asia/Qostanay"},
                                                    },
                                                ),
                                                datetime.timedelta(seconds=18000): {
                                                    "Asia/Qyzylorda"
                                                },
                                            },
                                        ),
                                        datetime.timedelta(seconds=21600): {
                                            "Asia/Samarkand"
                                        },
                                    },
                                ),
                            },
                        ),
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=19800): (
            datetime.datetime(1986, 1, 1, 18, 0),
            {
                datetime.timedelta(seconds=19800): (
                    datetime.datetime(1987, 10, 1, 18, 0),
                    {
                        datetime.timedelta(seconds=19800): (
                            datetime.datetime(1996, 5, 25, 15, 0),
                            {
                                datetime.timedelta(seconds=19800): {
                                    "Asia/Calcutta",
                                    "Asia/Kolkata",
                                },
                                datetime.timedelta(seconds=23400): {"Asia/Colombo"},
                            },
                        ),
                        datetime.timedelta(seconds=21600): {
                            "Asia/Thimbu",
                            "Asia/Thimphu",
                        },
                    },
                ),
                datetime.timedelta(seconds=20700): {"Asia/Kathmandu", "Asia/Katmandu"},
            },
        ),
        datetime.timedelta(seconds=21600): (
            datetime.datetime(1978, 1, 2, 0, 0),
            {
                datetime.timedelta(seconds=21600): (
                    datetime.datetime(1981, 4, 1, 18, 0),
                    {
                        datetime.timedelta(seconds=21600): (
                            datetime.datetime(2009, 6, 20, 18, 0),
                            {
                                datetime.timedelta(seconds=21600): (
                                    datetime.datetime(2009, 10, 18, 21, 0),
                                    {
                                        datetime.timedelta(seconds=18000): {
                                            "Antarctica/Mawson"
                                        },
                                        datetime.timedelta(seconds=21600): {
                                            "Asia/Kashgar",
                                            "Asia/Urumqi",
                                            "Etc/GMT-6",
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=25200): {
                                    "Asia/Dacca",
                                    "Asia/Dhaka",
                                },
                            },
                        ),
                        datetime.timedelta(seconds=25200): (
                            datetime.datetime(1991, 8, 31, 21, 0),
                            {
                                datetime.timedelta(seconds=18000): {"Asia/Bishkek"},
                                datetime.timedelta(seconds=21600): (
                                    datetime.datetime(1991, 9, 9, 15, 0),
                                    {
                                        datetime.timedelta(seconds=18000): {
                                            "Asia/Dushanbe"
                                        },
                                        datetime.timedelta(seconds=21600): (
                                            datetime.datetime(1992, 1, 19, 18, 0),
                                            {
                                                datetime.timedelta(seconds=18000): {
                                                    "Asia/Tashkent"
                                                },
                                                datetime.timedelta(seconds=21600): (
                                                    datetime.datetime(
                                                        2005, 3, 27, 15, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=21600
                                                        ): {"Asia/Almaty"},
                                                        datetime.timedelta(
                                                            seconds=25200
                                                        ): {"Asia/Omsk"},
                                                    },
                                                ),
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                    },
                ),
                datetime.timedelta(seconds=25200): {"Asia/Hovd"},
            },
        ),
        datetime.timedelta(seconds=23400): {
            "Asia/Rangoon",
            "Asia/Yangon",
            "Indian/Cocos",
        },
        datetime.timedelta(seconds=25200): (
            datetime.datetime(1978, 1, 2, 0, 0),
            {
                datetime.timedelta(seconds=25200): (
                    datetime.datetime(1981, 4, 1, 18, 0),
                    {
                        datetime.timedelta(seconds=25200): (
                            datetime.datetime(1994, 2, 1, 12, 0),
                            {
                                datetime.timedelta(0): {"Antarctica/Vostok"},
                                datetime.timedelta(seconds=25200): (
                                    datetime.datetime(2009, 10, 18, 21, 0),
                                    {
                                        datetime.timedelta(seconds=18000): {
                                            "Antarctica/Davis"
                                        },
                                        datetime.timedelta(seconds=25200): {
                                            "Asia/Bangkok",
                                            "Asia/Jakarta",
                                            "Asia/Phnom_Penh",
                                            "Asia/Vientiane",
                                            "Etc/GMT-7",
                                            "Indian/Christmas",
                                        },
                                    },
                                ),
                            },
                        ),
                        datetime.timedelta(seconds=28800): (
                            datetime.datetime(1993, 5, 23, 18, 0),
                            {
                                datetime.timedelta(seconds=25200): {"Asia/Novosibirsk"},
                                datetime.timedelta(seconds=28800): (
                                    datetime.datetime(1995, 5, 28, 18, 0),
                                    {
                                        datetime.timedelta(seconds=25200): {
                                            "Asia/Barnaul"
                                        },
                                        datetime.timedelta(seconds=28800): (
                                            datetime.datetime(2002, 5, 2, 0, 0),
                                            {
                                                datetime.timedelta(seconds=25200): {
                                                    "Asia/Tomsk"
                                                },
                                                datetime.timedelta(seconds=28800): (
                                                    datetime.datetime(
                                                        2010, 3, 28, 15, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=25200
                                                        ): {"Asia/Novokuznetsk"},
                                                        datetime.timedelta(
                                                            seconds=28800
                                                        ): {"Asia/Krasnoyarsk"},
                                                    },
                                                ),
                                            },
                                        ),
                                    },
                                ),
                            },
                        ),
                    },
                ),
                datetime.timedelta(seconds=28800): {
                    "Asia/Choibalsan",
                    "Asia/Ulaanbaatar",
                    "Asia/Ulan_Bator",
                },
            },
        ),
        datetime.timedelta(seconds=27000): {
            "Asia/Kuala_Lumpur",
            "Asia/Singapore",
            "Singapore",
        },
        datetime.timedelta(seconds=28800): (
            datetime.datetime(1970, 4, 19, 18, 0),
            {
                datetime.timedelta(seconds=28800): (
                    datetime.datetime(1974, 4, 1, 15, 0),
                    {
                        datetime.timedelta(seconds=28800): (
                            datetime.datetime(1974, 10, 27, 15, 0),
                            {
                                datetime.timedelta(seconds=28800): (
                                    datetime.datetime(1975, 6, 13, 21, 0),
                                    {
                                        datetime.timedelta(seconds=25200): {
                                            "Asia/Ho_Chi_Minh",
                                            "Asia/Saigon",
                                        },
                                        datetime.timedelta(seconds=28800): (
                                            datetime.datetime(1978, 3, 22, 21, 0),
                                            {
                                                datetime.timedelta(seconds=28800): (
                                                    datetime.datetime(
                                                        1981, 4, 1, 21, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=28800
                                                        ): (
                                                            datetime.datetime(
                                                                1986, 5, 4, 21, 0
                                                            ),
                                                            {
                                                                datetime.timedelta(
                                                                    seconds=28800
                                                                ): (
                                                                    datetime.datetime(
                                                                        1988,
                                                                        1,
                                                                        1,
                                                                        18,
                                                                        0,
                                                                    ),
                                                                    {
                                                                        datetime.timedelta(
                                                                            seconds=25200
                                                                        ): {
                                                                            "Asia/Pontianak"
                                                                        },
                                                                        datetime.timedelta(
                                                                            seconds=28800
                                                                        ): (
                                                                            datetime.datetime(
                                                                                2009,
                                                                                10,
                                                                                19,
                                                                                3,
                                                                                0,
                                                                            ),
                                                                            {
                                                                                datetime.timedelta(
                                                                                    seconds=28800
                                                                                ): {
                                                                                    "Asia/Brunei",
                                                                                    "Asia/Kuching",
                                                                                    "Asia/Makassar",
                                                                                    "Asia/Ujung_Pandang",
                                                                                    "Etc/GMT-8",
                                                                                },
                                                                                datetime.timedelta(
                                                                                    seconds=39600
                                                                                ): {
                                                                                    "Antarctica/Casey"
                                                                                },
                                                                            },
                                                                        ),
                                                                    },
                                                                ),
                                                                datetime.timedelta(
                                                                    seconds=32400
                                                                ): {
                                                                    "Asia/Chongqing",
                                                                    "Asia/Chungking",
                                                                    "Asia/Harbin",
                                                                    "Asia/Shanghai",
                                                                    "PRC",
                                                                },
                                                            },
                                                        ),
                                                        datetime.timedelta(
                                                            seconds=32400
                                                        ): {"Asia/Irkutsk"},
                                                    },
                                                ),
                                                datetime.timedelta(seconds=32400): {
                                                    "Asia/Manila"
                                                },
                                            },
                                        ),
                                    },
                                ),
                                datetime.timedelta(seconds=32400): {
                                    "Australia/Perth",
                                    "Australia/West",
                                },
                            },
                        ),
                        datetime.timedelta(seconds=32400): {"Asia/Taipei", "ROC"},
                    },
                ),
                datetime.timedelta(seconds=32400): {
                    "Asia/Hong_Kong",
                    "Asia/Macao",
                    "Asia/Macau",
                    "Hongkong",
                },
            },
        ),
        datetime.timedelta(seconds=31500): {"Australia/Eucla"},
        datetime.timedelta(seconds=32400): (
            datetime.datetime(1976, 5, 3, 18, 0),
            {
                datetime.timedelta(seconds=28800): {"Asia/Dili"},
                datetime.timedelta(seconds=32400): (
                    datetime.datetime(1981, 4, 1, 18, 0),
                    {
                        datetime.timedelta(seconds=32400): (
                            datetime.datetime(1987, 5, 10, 15, 0),
                            {
                                datetime.timedelta(seconds=32400): (
                                    datetime.datetime(2015, 8, 15, 15, 0),
                                    {
                                        datetime.timedelta(seconds=30600): {
                                            "Asia/Pyongyang"
                                        },
                                        datetime.timedelta(seconds=32400): {
                                            "Asia/Jayapura",
                                            "Asia/Tokyo",
                                            "Etc/GMT-9",
                                            "Japan",
                                            "Pacific/Palau",
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=36000): {
                                    "Asia/Seoul",
                                    "ROK",
                                },
                            },
                        ),
                        datetime.timedelta(seconds=36000): (
                            datetime.datetime(2004, 1, 1, 21, 0),
                            {
                                datetime.timedelta(seconds=32400): (
                                    datetime.datetime(2014, 10, 27, 0, 0),
                                    {
                                        datetime.timedelta(seconds=28800): {
                                            "Asia/Chita"
                                        },
                                        datetime.timedelta(seconds=32400): {
                                            "Asia/Yakutsk"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=36000): {"Asia/Khandyga"},
                            },
                        ),
                        datetime.timedelta(seconds=43200): {"Asia/Ust-Nera"},
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=34200): (
            datetime.datetime(1971, 10, 31, 21, 0),
            {
                datetime.timedelta(seconds=34200): {
                    "Australia/Darwin",
                    "Australia/North",
                },
                datetime.timedelta(seconds=37800): (
                    datetime.datetime(1982, 3, 7, 18, 0),
                    {
                        datetime.timedelta(seconds=34200): {
                            "Australia/Adelaide",
                            "Australia/South",
                        },
                        datetime.timedelta(seconds=37800): {
                            "Australia/Broken_Hill",
                            "Australia/Yancowinna",
                        },
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=36000): (
            datetime.datetime(1970, 4, 26, 15, 0),
            {
                datetime.timedelta(seconds=36000): (
                    datetime.datetime(1971, 10, 31, 21, 0),
                    {
                        datetime.timedelta(seconds=36000): (
                            datetime.datetime(1981, 3, 2, 0, 0),
                            {
                                datetime.timedelta(seconds=36000): (
                                    datetime.datetime(1981, 4, 1, 18, 0),
                                    {
                                        datetime.timedelta(seconds=36000): (
                                            datetime.datetime(2014, 12, 28, 21, 0),
                                            {
                                                datetime.timedelta(seconds=36000): {
                                                    "Antarctica/DumontDUrville",
                                                    "Etc/GMT-10",
                                                    "Pacific/Chuuk",
                                                    "Pacific/Port_Moresby",
                                                    "Pacific/Truk",
                                                    "Pacific/Yap",
                                                },
                                                datetime.timedelta(seconds=39600): {
                                                    "Pacific/Bougainville"
                                                },
                                            },
                                        ),
                                        datetime.timedelta(seconds=39600): {
                                            "Asia/Vladivostok"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=37800): {
                                    "Australia/LHI",
                                    "Australia/Lord_Howe",
                                },
                            },
                        ),
                        datetime.timedelta(seconds=39600): (
                            datetime.datetime(1972, 10, 29, 21, 0),
                            {
                                datetime.timedelta(seconds=36000): (
                                    datetime.datetime(1992, 10, 26, 0, 0),
                                    {
                                        datetime.timedelta(seconds=36000): {
                                            "Australia/Brisbane",
                                            "Australia/Queensland",
                                        },
                                        datetime.timedelta(seconds=39600): {
                                            "Australia/Lindeman"
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=39600): (
                                    datetime.datetime(1982, 3, 7, 18, 0),
                                    {
                                        datetime.timedelta(seconds=36000): {
                                            "Australia/Melbourne",
                                            "Australia/Victoria",
                                        },
                                        datetime.timedelta(seconds=39600): {
                                            "Australia/ACT",
                                            "Australia/Canberra",
                                            "Australia/NSW",
                                            "Australia/Sydney",
                                        },
                                    },
                                ),
                            },
                        ),
                    },
                ),
                datetime.timedelta(seconds=39600): {"Pacific/Guam", "Pacific/Saipan"},
            },
        ),
        datetime.timedelta(seconds=39600): (
            datetime.datetime(1970, 3, 8, 15, 0),
            {
                datetime.timedelta(seconds=36000): (
                    datetime.datetime(2010, 4, 4, 21, 0),
                    {
                        datetime.timedelta(seconds=36000): {
                            "Australia/Currie",
                            "Australia/Hobart",
                            "Australia/Tasmania",
                        },
                        datetime.timedelta(seconds=39600): {"Antarctica/Macquarie"},
                    },
                ),
                datetime.timedelta(seconds=39600): (
                    datetime.datetime(1973, 12, 23, 15, 0),
                    {
                        datetime.timedelta(seconds=39600): (
                            datetime.datetime(1977, 12, 4, 15, 0),
                            {
                                datetime.timedelta(seconds=39600): (
                                    datetime.datetime(1981, 4, 1, 18, 0),
                                    {
                                        datetime.timedelta(seconds=39600): {
                                            "Etc/GMT-11",
                                            "Pacific/Guadalcanal",
                                            "Pacific/Pohnpei",
                                            "Pacific/Ponape",
                                        },
                                        datetime.timedelta(seconds=43200): (
                                            datetime.datetime(1997, 3, 30, 15, 0),
                                            {
                                                datetime.timedelta(seconds=39600): {
                                                    "Asia/Sakhalin"
                                                },
                                                datetime.timedelta(seconds=43200): (
                                                    datetime.datetime(
                                                        2014, 10, 26, 18, 0
                                                    ),
                                                    {
                                                        datetime.timedelta(
                                                            seconds=36000
                                                        ): {"Asia/Magadan"},
                                                        datetime.timedelta(
                                                            seconds=39600
                                                        ): {"Asia/Srednekolymsk"},
                                                    },
                                                ),
                                            },
                                        ),
                                    },
                                ),
                                datetime.timedelta(seconds=43200): {"Pacific/Noumea"},
                            },
                        ),
                        datetime.timedelta(seconds=43200): {"Pacific/Efate"},
                    },
                ),
            },
        ),
        datetime.timedelta(seconds=41400): (
            datetime.datetime(1974, 10, 27, 15, 0),
            {
                datetime.timedelta(seconds=41400): {"Pacific/Nauru"},
                datetime.timedelta(seconds=45000): {"Pacific/Norfolk"},
            },
        ),
        datetime.timedelta(seconds=43200): (
            datetime.datetime(1974, 11, 3, 21, 0),
            {
                datetime.timedelta(seconds=43200): (
                    datetime.datetime(1981, 4, 1, 15, 0),
                    {
                        datetime.timedelta(seconds=43200): (
                            datetime.datetime(1998, 11, 1, 18, 0),
                            {
                                datetime.timedelta(seconds=43200): (
                                    datetime.datetime(1999, 1, 1, 18, 0),
                                    {
                                        datetime.timedelta(seconds=39600): {
                                            "Pacific/Kosrae"
                                        },
                                        datetime.timedelta(seconds=43200): {
                                            "Etc/GMT-12",
                                            "Pacific/Funafuti",
                                            "Pacific/Majuro",
                                            "Pacific/Tarawa",
                                            "Pacific/Wake",
                                            "Pacific/Wallis",
                                        },
                                    },
                                ),
                                datetime.timedelta(seconds=46800): {"Pacific/Fiji"},
                            },
                        ),
                        datetime.timedelta(seconds=46800): {"Asia/Kamchatka"},
                    },
                ),
                datetime.timedelta(seconds=46800): {
                    "Antarctica/McMurdo",
                    "Antarctica/South_Pole",
                    "NZ",
                    "Pacific/Auckland",
                },
            },
        ),
        datetime.timedelta(seconds=45900): {"NZ-CHAT", "Pacific/Chatham"},
        datetime.timedelta(seconds=46800): (
            datetime.datetime(1981, 4, 1, 15, 0),
            {
                datetime.timedelta(seconds=46800): (
                    datetime.datetime(1999, 10, 7, 21, 0),
                    {
                        datetime.timedelta(seconds=46800): {"Etc/GMT-13"},
                        datetime.timedelta(seconds=50400): {"Pacific/Tongatapu"},
                    },
                ),
                datetime.timedelta(seconds=50400): {"Asia/Anadyr"},
            },
        ),
        datetime.timedelta(seconds=50400): {"Etc/GMT-14"},
    },
)


__all__ = ["lookup"]



""":rfc:`5545` VEVENT component."""

from __future__ import annotations

import uuid
from datetime import date, datetime, timedelta
from typing import TYPE_CHECKING, Literal, Sequence

from icalendar.attr import (
    CONCEPTS_TYPE_SETTER,
    LINKS_TYPE_SETTER,
    RELATED_TO_TYPE_SETTER,
    X_MOZ_LASTACK_property,
    X_MOZ_SNOOZE_TIME_property,
    attendees_property,
    categories_property,
    class_property,
    color_property,
    conferences_property,
    contacts_property,
    create_single_property,
    description_property,
    exdates_property,
    get_duration_property,
    get_end_property,
    get_start_end_duration_with_validation,
    get_start_property,
    images_property,
    location_property,
    organizer_property,
    priority_property,
    property_del_duration,
    property_doc_duration_template,
    property_get_duration,
    property_set_duration,
    rdates_property,
    rrules_property,
    sequence_property,
    set_duration_with_locking,
    set_end_with_locking,
    set_start_with_locking,
    status_property,
    summary_property,
    transparency_property,
    uid_property,
    url_property,
)
from icalendar.cal.component import Component
from icalendar.cal.examples import get_example

if TYPE_CHECKING:
    from icalendar.alarms import Alarms
    from icalendar.enums import CLASS, STATUS, TRANSP
    from icalendar.prop import vCalAddress
    from icalendar.prop.conference import Conference


class Event(Component):
    """A grouping of component properties that describe an event.

    Description:
        A "VEVENT" calendar component is a grouping of
        component properties, possibly including "VALARM" calendar
        components, that represents a scheduled amount of time on a
        calendar.  For example, it can be an activity; such as a one-hour
        long, department meeting from 8:00 AM to 9:00 AM, tomorrow.
        Generally, an event will take up time on an individual calendar.
        Hence, the event will appear as an opaque interval in a search for
        busy time.  Alternately, the event can have its Time Transparency
        set to "TRANSPARENT" in order to prevent blocking of the event in
        searches for busy time.

        The "VEVENT" is also the calendar component used to specify an
        anniversary or daily reminder within a calendar.  These events
        have a DATE value type for the "DTSTART" property instead of the
        default value type of DATE-TIME.  If such a "VEVENT" has a "DTEND"
        property, it MUST be specified as a DATE value also.  The
        anniversary type of "VEVENT" can span more than one date (i.e.,
        "DTEND" property value is set to a calendar date after the
        "DTSTART" property value).  If such a "VEVENT" has a "DURATION"
        property, it MUST be specified as a "dur-day" or "dur-week" value.

        The "DTSTART" property for a "VEVENT" specifies the inclusive
        start of the event.  For recurring events, it also specifies the
        very first instance in the recurrence set.  The "DTEND" property
        for a "VEVENT" calendar component specifies the non-inclusive end
        of the event.  For cases where a "VEVENT" calendar component
        specifies a "DTSTART" property with a DATE value type but no
        "DTEND" nor "DURATION" property, the event's duration is taken to
        be one day.  For cases where a "VEVENT" calendar component
        specifies a "DTSTART" property with a DATE-TIME value type but no
        "DTEND" property, the event ends on the same calendar date and
        time of day specified by the "DTSTART" property.

        The "VEVENT" calendar component cannot be nested within another
        calendar component.  However, "VEVENT" calendar components can be
        related to each other or to a "VTODO" or to a "VJOURNAL" calendar
        component with the "RELATED-TO" property.

    Examples:
        The following is an example of the "VEVENT" calendar
        component used to represent a meeting that will also be opaque to
        searches for busy time:

        .. code-block:: text

            BEGIN:VEVENT
            UID:19970901T130000Z-123401@example.com
            DTSTAMP:19970901T130000Z
            DTSTART:19970903T163000Z
            DTEND:19970903T190000Z
            SUMMARY:Annual Employee Review
            CLASS:PRIVATE
            CATEGORIES:BUSINESS,HUMAN RESOURCES
            END:VEVENT

        The following is an example of the "VEVENT" calendar component
        used to represent a reminder that will not be opaque, but rather
        transparent, to searches for busy time:

        .. code-block:: text

            BEGIN:VEVENT
            UID:19970901T130000Z-123402@example.com
            DTSTAMP:19970901T130000Z
            DTSTART:19970401T163000Z
            DTEND:19970402T010000Z
            SUMMARY:Laurel is in sensitivity awareness class.
            CLASS:PUBLIC
            CATEGORIES:BUSINESS,HUMAN RESOURCES
            TRANSP:TRANSPARENT
            END:VEVENT

        The following is an example of the "VEVENT" calendar component
        used to represent an anniversary that will occur annually:

        .. code-block:: text

            BEGIN:VEVENT
            UID:19970901T130000Z-123403@example.com
            DTSTAMP:19970901T130000Z
            DTSTART;VALUE=DATE:19971102
            SUMMARY:Our Blissful Anniversary
            TRANSP:TRANSPARENT
            CLASS:CONFIDENTIAL
            CATEGORIES:ANNIVERSARY,PERSONAL,SPECIAL OCCASION
            RRULE:FREQ=YEARLY
            END:VEVENT

        The following is an example of the "VEVENT" calendar component
        used to represent a multi-day event scheduled from June 28th, 2007
        to July 8th, 2007 inclusively.  Note that the "DTEND" property is
        set to July 9th, 2007, since the "DTEND" property specifies the
        non-inclusive end of the event.

        .. code-block:: text

            BEGIN:VEVENT
            UID:20070423T123432Z-541111@example.com
            DTSTAMP:20070423T123432Z
            DTSTART;VALUE=DATE:20070628
            DTEND;VALUE=DATE:20070709
            SUMMARY:Festival International de Jazz de Montreal
            TRANSP:TRANSPARENT
            END:VEVENT

        Create a new Event:

        .. code-block:: python

            >>> from icalendar import Event
            >>> from datetime import datetime
            >>> event = Event.new(start=datetime(2021, 1, 1, 12, 30, 0))
            >>> print(event.to_ical())
            BEGIN:VEVENT
            DTSTART:20210101T123000
            DTSTAMP:20250517T080612Z
            UID:d755cef5-2311-46ed-a0e1-6733c9e15c63
            END:VEVENT

    """

    name = "VEVENT"

    canonical_order = (
        "SUMMARY",
        "DTSTART",
        "DTEND",
        "DURATION",
        "DTSTAMP",
        "UID",
        "RECURRENCE-ID",
        "SEQUENCE",
        "RRULE",
        "RDATE",
        "EXDATE",
    )

    required = (
        "UID",
        "DTSTAMP",
    )
    singletons = (
        "CLASS",
        "CREATED",
        "COLOR",
        "DESCRIPTION",
        "DTSTART",
        "GEO",
        "LAST-MODIFIED",
        "LOCATION",
        "ORGANIZER",
        "PRIORITY",
        "DTSTAMP",
        "SEQUENCE",
        "STATUS",
        "SUMMARY",
        "TRANSP",
        "URL",
        "RECURRENCE-ID",
        "DTEND",
        "DURATION",
        "UID",
    )
    exclusive = (
        "DTEND",
        "DURATION",
    )
    multiple = (
        "ATTACH",
        "ATTENDEE",
        "CATEGORIES",
        "COMMENT",
        "CONTACT",
        "EXDATE",
        "RSTATUS",
        "RELATED",
        "RESOURCES",
        "RDATE",
        "RRULE",
    )
    ignore_exceptions = True

    @property
    def alarms(self) -> Alarms:
        """Compute the alarm times for this component.

        >>> from icalendar import Event
        >>> event = Event.example("rfc_9074_example_1")
        >>> len(event.alarms.times)
        1
        >>> alarm_time = event.alarms.times[0]
        >>> alarm_time.trigger  # The time when the alarm pops up
        datetime.datetime(2021, 3, 2, 10, 15, tzinfo=ZoneInfo(key='America/New_York'))
        >>> alarm_time.is_active()  # This alarm has not been acknowledged
        True

        Note that this only uses DTSTART and DTEND, but ignores
        RDATE, EXDATE, and RRULE properties.
        """
        from icalendar.alarms import Alarms

        return Alarms(self)

    @classmethod
    def example(cls, name: str = "rfc_9074_example_3") -> Event:
        """Return the calendar example with the given name."""
        return cls.from_ical(get_example("events", name))

    DTSTART = create_single_property(
        "DTSTART",
        "dt",
        (datetime, date),
        date,
        'The "DTSTART" property for a "VEVENT" specifies the inclusive start of the event.',  # noqa: E501
    )
    DTEND = create_single_property(
        "DTEND",
        "dt",
        (datetime, date),
        date,
        'The "DTEND" property for a "VEVENT" calendar component specifies the non-inclusive end of the event.',  # noqa: E501
    )

    def _get_start_end_duration(self):
        """Verify the calendar validity and return the right attributes."""
        return get_start_end_duration_with_validation(
            self, "DTSTART", "DTEND", "VEVENT"
        )

    DURATION = property(
        property_get_duration,
        property_set_duration,
        property_del_duration,
        property_doc_duration_template.format(component="VEVENT"),
    )

    @property
    def duration(self) -> timedelta:
        """The duration of the VEVENT.

        Returns the DURATION property if set, otherwise calculated from start and end.
        When setting duration, the end time is automatically calculated from start +
        duration.
        You can set the duration to automatically adjust the end time while keeping
        start locked.

        Setting the duration will:
        1. Keep the start time locked (unchanged)
        2. Adjust the end time to start + duration
        3. Remove any existing DTEND property
        4. Set the DURATION property
        """
        return get_duration_property(self)

    @duration.setter
    def duration(self, value: timedelta):
        if not isinstance(value, timedelta):
            raise TypeError(f"Use timedelta, not {type(value).__name__}.")

        # Use the set_duration method with default start-locked behavior
        self.set_duration(value, locked="start")

    @property
    def start(self) -> date | datetime:
        """The start of the event.

        Invalid values raise an InvalidCalendar.
        If there is no start, we also raise an IncompleteComponent error.

        You can get the start, end and duration of an event as follows:

        >>> from datetime import datetime
        >>> from icalendar import Event
        >>> event = Event()
        >>> event.start = datetime(2021, 1, 1, 12)
        >>> event.end = datetime(2021, 1, 1, 12, 30) # 30 minutes
        >>> event.duration  # 1800 seconds == 30 minutes
        datetime.timedelta(seconds=1800)
        >>> print(event.to_ical())
        BEGIN:VEVENT
        DTSTART:20210101T120000
        DTEND:20210101T123000
        END:VEVENT
        """
        return get_start_property(self)

    @start.setter
    def start(self, start: date | datetime | None):
        """Set the start."""
        self.DTSTART = start

    @property
    def end(self) -> date | datetime:
        """The end of the event.

        Invalid values raise an InvalidCalendar error.
        If there is no end, we also raise an IncompleteComponent error.
        """
        return get_end_property(self, "DTEND")

    @end.setter
    def end(self, end: date | datetime | None):
        """Set the end."""
        self.DTEND = end

    def set_duration(
        self, duration: timedelta | None, locked: Literal["start", "end"] = "start"
    ):
        """Set the duration of the event relative to either start or end.

        Args:
            duration: The duration to set, or None to convert to DURATION property
            locked: Which property to keep unchanged ('start' or 'end')
        """
        set_duration_with_locking(self, duration, locked, "DTEND")

    def set_start(
        self, start: date | datetime, locked: Literal["duration", "end"] | None = None
    ):
        """Set the start and keep the duration or end of the event.

        Args:
            start: The start time to set
            locked: Which property to keep unchanged ('duration', 'end', or None
                for auto-detect)
        """
        set_start_with_locking(self, start, locked, "DTEND")

    def set_end(
        self, end: date | datetime, locked: Literal["start", "duration"] = "start"
    ):
        """Set the end of the component, keeping either the start or the duration same.

        Args:
            end: The end time to set
            locked: Which property to keep unchanged ('start' or 'duration')
        """
        set_end_with_locking(self, end, locked, "DTEND")

    X_MOZ_SNOOZE_TIME = X_MOZ_SNOOZE_TIME_property
    X_MOZ_LASTACK = X_MOZ_LASTACK_property
    color = color_property
    sequence = sequence_property
    categories = categories_property
    rdates = rdates_property
    exdates = exdates_property
    rrules = rrules_property
    uid = uid_property
    summary = summary_property
    description = description_property
    classification = class_property
    url = url_property
    organizer = organizer_property
    location = location_property
    priority = priority_property
    contacts = contacts_property
    transparency = transparency_property
    status = status_property
    attendees = attendees_property
    images = images_property
    conferences = conferences_property

    @classmethod
    def new(
        cls,
        /,
        attendees: list[vCalAddress] | None = None,
        categories: Sequence[str] = (),
        classification: CLASS | None = None,
        color: str | None = None,
        comments: list[str] | str | None = None,
        concepts: CONCEPTS_TYPE_SETTER = None,
        conferences: list[Conference] | None = None,
        contacts: list[str] | str | None = None,
        created: date | None = None,
        description: str | None = None,
        end: date | datetime | None = None,
        last_modified: date | None = None,
        links: LINKS_TYPE_SETTER = None,
        location: str | None = None,
        organizer: vCalAddress | str | None = None,
        priority: int | None = None,
        refids: list[str] | str | None = None,
        related_to: RELATED_TO_TYPE_SETTER = None,
        sequence: int | None = None,
        stamp: date | None = None,
        start: date | datetime | None = None,
        status: STATUS | None = None,
        transparency: TRANSP | None = None,
        summary: str | None = None,
        uid: str | uuid.UUID | None = None,
        url: str | None = None,
    ):
        """Create a new event with all required properties.

        This creates a new Event in accordance with :rfc:`5545`.

        Arguments:
            attendees: The :attr:`attendees` of the event.
            categories: The :attr:`categories` of the event.
            classification: The :attr:`classification` of the event.
            color: The :attr:`color` of the event.
            comments: The :attr:`~icalendar.Component.comments` of the event.
            concepts: The :attr:`~icalendar.Component.concepts` of the event.
            conferences: The :attr:`conferences` of the event.
            created: The :attr:`~icalendar.Component.created` of the event.
            description: The :attr:`description` of the event.
            end: The :attr:`end` of the event.
            last_modified: The :attr:`~icalendar.Component.last_modified` of the event.
            links: The :attr:`~icalendar.Component.links` of the event.
            location: The :attr:`location` of the event.
            organizer: The :attr:`organizer` of the event.
            priority: The :attr:`priority` of the event.
            refids: :attr:`~icalendar.Component.refids` of the event.
            related_to: :attr:`~icalendar.Component.related_to` of the event.
            sequence: The :attr:`sequence` of the event.
            stamp: The :attr:`~icalendar.Component.stamp` of the event.
                If None, this is set to the current time.
            start: The :attr:`start` of the event.
            status: The :attr:`status` of the event.
            summary: The :attr:`summary` of the event.
            transparency: The :attr:`transparency` of the event.
            uid: The :attr:`uid` of the event.
                If None, this is set to a new :func:`uuid.uuid4`.
            url: The :attr:`url` of the event.

        Returns:
            :class:`Event`

        Raises:
            InvalidCalendar: If the content is not valid according to :rfc:`5545`.

        .. warning:: As time progresses, we will be stricter with the validation.
        """
        event: Event = super().new(
            stamp=stamp if stamp is not None else cls._utc_now(),
            created=created,
            last_modified=last_modified,
            comments=comments,
            links=links,
            related_to=related_to,
            refids=refids,
            concepts=concepts,
        )
        event.summary = summary
        event.description = description
        event.uid = uid if uid is not None else uuid.uuid4()
        event.start = start
        event.end = end
        event.color = color
        event.categories = categories
        event.sequence = sequence
        event.classification = classification
        event.url = url
        event.organizer = organizer
        event.location = location
        event.priority = priority
        event.transparency = transparency
        event.contacts = contacts
        event.status = status
        event.attendees = attendees
        event.conferences = conferences

        if cls._validate_new:
            cls._validate_start_and_end(start, end)
        return event


__all__ = ["Event"]



import pytest

from icalendar.prop import vBoolean


def test_true():
    assert vBoolean(True).to_ical() == b"TRUE"


def test_false():
    assert vBoolean(0).to_ical() == b"FALSE"


def test_roundtrip():
    assert vBoolean.from_ical(vBoolean(True).to_ical()) == True
    assert vBoolean.from_ical("true") == True


def test_error():
    """Error: key not exists"""
    with pytest.raises(ValueError):
        vBoolean.from_ical("ture")



"""tests ensuring that *the* way of doing things works"""

import datetime

import pytest

from icalendar import Availability, Available, Calendar, Event, Timezone


def test_creating_calendar_with_unicode_fields(calendars, utc):
    """create a calendar with events that contain unicode characters in their fields"""
    cal = Calendar()
    cal.add("PRODID", "-//Plönë.org//NONSGML plone.app.event//EN")
    cal.add("VERSION", "2.0")
    cal.add("X-WR-CALNAME", "äöü ÄÖÜ €")
    cal.add("X-WR-CALDESC", "test non ascii: äöü ÄÖÜ €")
    cal.add("X-WR-RELCALID", "12345")

    event = Event()
    event.add("DTSTART", datetime.datetime(2010, 10, 10, 10, 0, 0, tzinfo=utc))
    event.add("DTEND", datetime.datetime(2010, 10, 10, 12, 0, 0, tzinfo=utc))
    event.add("CREATED", datetime.datetime(2010, 10, 10, 0, 0, 0, tzinfo=utc))
    event.add("UID", "123456")
    event.add("SUMMARY", "Non-ASCII Test: ÄÖÜ äöü €")
    event.add("DESCRIPTION", "icalendar should be able to de/serialize non-ascii.")
    event.add("LOCATION", "Tribstrül")
    cal.add_component(event)

    # test_create_event_simple
    event1 = Event()
    event1.add("DTSTART", datetime.datetime(2010, 10, 10, 0, 0, 0, tzinfo=utc))
    event1.add("SUMMARY", "åäö")
    cal.add_component(event1)

    # test_unicode_parameter_name
    # test for issue #80 https://github.com/collective/icalendar/issues/80
    event2 = Event()
    event2.add("DESCRIPTION", "äöüßÄÖÜ")
    cal.add_component(event2)

    assert cal.to_ical() == calendars.created_calendar_with_unicode_fields.raw_ics


@pytest.mark.parametrize(
    ("component", "example"),
    [
        (Calendar, "example"),
        (Calendar, "example.ics"),
        (Event, "event_with_rsvp"),
        (Timezone, "pacific_fiji"),
    ],
)
def test_component_has_examples(tzp, calendars, timezones, events, component, example):
    """Check that the examples function works."""
    mapping = {Calendar: calendars, Event: events, Timezone: timezones}
    example_component = component.example(example)
    expected_component = mapping[component][example]
    assert example_component == expected_component


def test_invalid_examples_lists_the_others():
    """We need a bit of guidance here."""
    with pytest.raises(ValueError) as e:
        Calendar.example("does not exist")
    assert "example.ics" in str(e.value)


@pytest.mark.parametrize(
    "component", [Calendar, Event, Timezone, Available, Availability]
)
def test_default_example(component):
    """Check that we have a default example."""
    example = component.example()
    assert isinstance(example, component)



"""This implements the sub-component "AVAILABLE" of "VAVAILABILITY".

This is specified in :rfc:`7953`.
"""

from __future__ import annotations

import uuid
from datetime import datetime
from typing import TYPE_CHECKING, Optional, Sequence

from icalendar.attr import (
    CONCEPTS_TYPE_SETTER,
    LINKS_TYPE_SETTER,
    RELATED_TO_TYPE_SETTER,
    categories_property,
    contacts_property,
    description_property,
    duration_property,
    exdates_property,
    location_property,
    rdates_property,
    rfc_7953_dtend_property,
    rfc_7953_dtstart_property,
    rfc_7953_duration_property,
    rfc_7953_end_property,
    rrules_property,
    sequence_property,
    summary_property,
    uid_property,
)
from icalendar.cal.examples import get_example
from icalendar.error import InvalidCalendar

from .component import Component

if TYPE_CHECKING:
    from datetime import date


class Available(Component):
    """Sub-component of "VAVAILABILITY from :rfc:`7953`.

    Description:
        "AVAILABLE" subcomponents are used to indicate periods of free
        time within the time range of the enclosing "VAVAILABILITY"
        component.  "AVAILABLE" subcomponents MAY include recurrence
        properties to specify recurring periods of time, which can be
        overridden using normal iCalendar recurrence behavior (i.e., use
        of the "RECURRENCE-ID" property).

    Examples:
        This is a recurring "AVAILABLE" subcomponent:

        .. code-block:: text

            BEGIN:AVAILABLE
            UID:57DD4AAF-3835-46B5-8A39-B3B253157F01
            SUMMARY:Monday to Friday from 9:00 to 17:00
            DTSTART;TZID=America/Denver:20111023T090000
            DTEND;TZID=America/Denver:20111023T170000
            RRULE:FREQ=WEEKLY;BYDAY=MO,TU,WE,TH,FR
            LOCATION:Denver
            END:AVAILABLE

        You can get the same example from :meth:`example`:

        .. code-block: pycon

            >>> from icalendar import Available
            >>> a = Available.example()
            >>> str(a.summary)
            'Monday to Friday from 9:00 to 17:00'

    """

    name = "AVAILABLE"

    summary = summary_property
    description = description_property
    sequence = sequence_property
    categories = categories_property
    uid = uid_property
    location = location_property
    contacts = contacts_property
    exdates = exdates_property
    rdates = rdates_property
    rrules = rrules_property

    start = DTSTART = rfc_7953_dtstart_property
    DTEND = rfc_7953_dtend_property
    DURATION = duration_property("Available")
    duration = rfc_7953_duration_property
    end = rfc_7953_end_property

    @classmethod
    def new(
        cls,
        /,
        categories: Sequence[str] = (),
        comments: list[str] | str | None = None,
        concepts: CONCEPTS_TYPE_SETTER = None,
        contacts: list[str] | str | None = None,
        created: Optional[date] = None,
        description: Optional[str] = None,
        end: Optional[datetime] = None,
        last_modified: Optional[date] = None,
        links: LINKS_TYPE_SETTER = None,
        location: Optional[str] = None,
        refids: list[str] | str | None = None,
        related_to: RELATED_TO_TYPE_SETTER = None,
        sequence: Optional[int] = None,
        stamp: Optional[date] = None,
        start: Optional[datetime] = None,
        summary: Optional[str] = None,
        uid: Optional[str | uuid.UUID] = None,
    ):
        """Create a new Available component with all required properties.

        This creates a new Available component in accordance with :rfc:`7953`.

        Arguments:
            categories: The :attr:`categories` of the Available component.
            comments: The :attr:`~icalendar.Component.comments` of the Available
                component.
            concepts: The :attr:`~icalendar.Component.concepts` of the Available
                component.
            contacts: The :attr:`contacts` of the Available component.
            created: The :attr:`~icalendar.Component.created` of the Available
                component.
            description: The :attr:`description` of the Available component.
            end: The :attr:`end` of the Available component.
            last_modified: The :attr:`~icalendar.Component.last_modified` of the
                Available component.
            links: The :attr:`~icalendar.Component.links` of the Available component.
            location: The :attr:`location` of the Available component.
            refids: :attr:`~icalendar.Component.refids` of the Available component.
            related_to: :attr:`~icalendar.Component.related_to` of the Available
                component.
            sequence: The :attr:`sequence` of the Available component.
            stamp: The :attr:`~icalendar.Component.stamp` of the Available component.
                If None, this is set to the current time.
            start: The :attr:`start` of the Available component.
            summary: The :attr:`summary` of the Available component.
            uid: The :attr:`uid` of the Available component.
                If None, this is set to a new :func:`uuid.uuid4`.

        Returns:
            :class:`Available`

        Raises:
            InvalidCalendar: If the content is not valid according to :rfc:`7953`.

        .. warning:: As time progresses, we will be stricter with the validation.
        """
        available: Available = super().new(
            stamp=stamp if stamp is not None else cls._utc_now(),
            created=created,
            last_modified=last_modified,
            comments=comments,
            links=links,
            related_to=related_to,
            refids=refids,
            concepts=concepts,
        )
        available.summary = summary
        available.description = description
        available.uid = uid if uid is not None else uuid.uuid4()
        available.sequence = sequence
        available.categories = categories
        available.location = location
        available.contacts = contacts

        if cls._validate_new:
            if end is not None and (
                not isinstance(end, datetime) or end.tzinfo is None
            ):
                raise InvalidCalendar(
                    "Available end must be a datetime with a timezone"
                )
            if not isinstance(start, datetime) or start.tzinfo is None:
                raise InvalidCalendar(
                    "Available start must be a datetime with a timezone"
                )
            available._validate_start_and_end(start, end)
        available.start = start
        available.end = end
        return available

    @classmethod
    def example(cls, name: str = "rfc_7953_1") -> Available:
        """Return the calendar example with the given name."""
        return cls.from_ical(get_example("availabilities", name)).available[0]


__all__ = ["Available"]



"""This package contains all functionality for timezones."""

from .tzid import is_utc, tzid_from_dt, tzid_from_tzinfo, tzids_from_tzinfo
from .tzp import TZP

tzp = TZP()


def use_pytz():
    """Use pytz as the implementation that looks up and creates timezones."""
    tzp.use_pytz()


def use_zoneinfo():
    """Use zoneinfo as the implementation that looks up and creates timezones."""
    tzp.use_zoneinfo()


__all__ = [
    "TZP",
    "is_utc",
    "tzid_from_dt",
    "tzid_from_tzinfo",
    "tzids_from_tzinfo",
    "tzp",
    "use_pytz",
    "use_zoneinfo",
]



"""Tests for jCal running on all ics files."""

import json
from datetime import datetime
from pprint import pprint

from icalendar.cal.alarm import Alarm
from icalendar.timezone.tzid import is_utc


def test_to_jcal_can_be_json_serialized(source_file):
    """Check that all calendars can be converted to JCAL and serialized to JSON."""
    jcal = source_file.to_jcal()
    s = json.dumps(jcal)
    assert s


def test_trigger(tzp):
    """Check jCal loading of TRIGGER."""
    alarm = Alarm()
    alarm.TRIGGER = tzp.localize_utc(datetime(2022, 1, 1))
    assert is_utc(alarm.TRIGGER)
    jcal = alarm.to_jcal()
    pprint(jcal)
    alarm2 = Alarm.from_jcal(jcal)
    assert alarm2.TRIGGER.replace(tzinfo=None) == datetime(2022, 1, 1)
    assert is_utc(alarm2.TRIGGER)


def test_trigger_from_example(events):
    """Check jCal loading of TRIGGER."""
    alarm: Alarm = events.rfc_9074_example_proximity.subcomponents[0]
    print(alarm["TRIGGER"])
    jcal = alarm.to_jcal()
    pprint(jcal)
    alarm2 = Alarm.from_jcal(jcal)
    assert alarm2 == alarm
    assert is_utc(alarm2.TRIGGER)
